==> youtui-center-api-0.0.1.1-yuanwei2-20180612.080427-3-sources.jar: cn/com/duiba/tuia/youtui/center/api/dto/youtui/YoutuiCyapDto.java <==
package cn.com.duiba.tuia.youtui.center.api.dto.youtui;

import java.io.Serializable;

/**
 * Created by xuefeng on 2018/5/17.
 */
public class  YoutuiCyapDto implements Serializable {

    private static final long serialVersionUID = 1L;

    Long                      id;

    /** 内容ID */
    private Long              contentId;

    /** 内容名称 */
    private String            contentName;

    /** 活动类型 */
    private Integer           contentType;

    /** 活动是否开启 */
    private Boolean           isPublish;

    /** 是否已删除 */
    private Boolean           isDelete;


    /** 是否被置顶 */
    private Integer           isTop;

    /** 活动标签 */
    private String            tag;

    /** 推广计划名称 */
    private String            planTitle;

    /** 推广计划描述 */
    private String            description;

    /** 活动皮肤类型 */
    private String            subType;

    /** 微信分享图片 */
    private String            wxShareImg;

    /** 微信分享title */
    private String            wxShareTitle;

    /** 微信分享信息 */
    private String            wxShareInfo;

    /** 额外信息*/
    private String            ext_info;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getContentId() {
        return contentId;
    }

    public void setContentId(Long contentId) {
        this.contentId = contentId;
    }

    public String getContentName() {
        return contentName;
    }

    public void setContentName(String contentName) {
        this.contentName = contentName;
    }

    public Integer getContentType() {
        return contentType;
    }

    public void setContentType(Integer contentType) {
        this.contentType = contentType;
    }

    public Boolean getPublish() {
        return isPublish;
    }

    public void setPublish(Boolean publish) {
        isPublish = publish;
    }

    public Boolean getDelete() {
        return isDelete;
    }

    public void setDelete(Boolean delete) {
        isDelete = delete;
    }

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag;
    }

    public String getPlanTitle() {
        return planTitle;
    }

    public void setPlanTitle(String planTitle) {
        this.planTitle = planTitle;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getSubType() {
        return subType;
    }

    public void setSubType(String subType) {
        this.subType = subType;
    }

    public String getWxShareImg() {
        return wxShareImg;
    }

    public void setWxShareImg(String wxShareImg) {
        this.wxShareImg = wxShareImg;
    }

    public String getWxShareTitle() {
        return wxShareTitle;
    }

    public void setWxShareTitle(String wxShareTitle) {
        this.wxShareTitle = wxShareTitle;
    }

    public String getWxShareInfo() {
        return wxShareInfo;
    }

    public void setWxShareInfo(String wxShareInfo) {
        this.wxShareInfo = wxShareInfo;
    }

    public String getExt_info() {
        return ext_info;
    }

    public void setExt_info(String ext_info) {
        this.ext_info = ext_info;
    }

    public Integer getIsTop() {
        return isTop;
    }

    public void setIsTop(Integer isTop) {
        this.isTop = isTop;
    }
}

==> youtui-center-api-0.0.1.11-yuanwei3-20180731.083559-5-sources.jar: cn/com/duiba/tuia/youtui/center/api/dto/youtui/YoutuiCyapDto.java <==
package cn.com.duiba.tuia.youtui.center.api.dto.youtui;

import java.io.Serializable;


/**
 * Created by xuefeng on 2018/5/17.
 */
public class  YoutuiCyapDto implements Serializable {

    private static final long serialVersionUID = 1L;

    Long                      id;

    /** 内容ID */
    private Long              contentId;

    /** 内容名称 */
    private String            contentName;

    /** 活动类型 */
    private Integer           contentType;

    /** 活动是否开启 */
    private Boolean           isPublish;

    /** 是否已删除 */
    private Boolean           isDelete;


    /**
     * 皮肤名字
     */
    private String            skinName;


    /** 是否被置顶 */
    private Long           isTopSort;

    /** 活动标签 */
    private String            tag;

    /** 推广计划名称 */
    private String            planTitle;

    /** 推广计划描述 */
    private String            description;

    /** 活动皮肤类型 */
    private String            subType;

    /** 微信分享图片 */
    private String            wxShareImg;

    /** 微信分享title */
    private String            wxShareTitle;

    /** 微信分享信息 */
    private String            wxShareInfo;

    /** 额外信息*/
    private String            ext_info;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getContentId() {
        return contentId;
    }

    public void setContentId(Long contentId) {
        this.contentId = contentId;
    }

    public String getContentName() {
        return contentName;
    }

    public void setContentName(String contentName) {
        this.contentName = contentName;
    }

    public Integer getContentType() {
        return contentType;
    }

    public void setContentType(Integer contentType) {
        this.contentType = contentType;
    }

    public Boolean getPublish() {
        return isPublish;
    }

    public void setPublish(Boolean publish) {
        isPublish = publish;
    }

    public Boolean getDelete() {
        return isDelete;
    }

    public void setDelete(Boolean delete) {
        isDelete = delete;
    }

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag;
    }

    public String getPlanTitle() {
        return planTitle;
    }

    public void setPlanTitle(String planTitle) {
        this.planTitle = planTitle;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getSubType() {
        return subType;
    }

    public void setSubType(String subType) {
        this.subType = subType;
    }

    public String getWxShareImg() {
        return wxShareImg;
    }

    public void setWxShareImg(String wxShareImg) {
        this.wxShareImg = wxShareImg;
    }

    public String getWxShareTitle() {
        return wxShareTitle;
    }

    public void setWxShareTitle(String wxShareTitle) {
        this.wxShareTitle = wxShareTitle;
    }

    public String getWxShareInfo() {
        return wxShareInfo;
    }

    public void setWxShareInfo(String wxShareInfo) {
        this.wxShareInfo = wxShareInfo;
    }

    public String getExt_info() {
        return ext_info;
    }

    public void setExt_info(String ext_info) {
        this.ext_info = ext_info;
    }

    public Long getIsTopSort() {
        return isTopSort;
    }

    public void setIsTopSort(Long isTopSort) {
        this.isTopSort = isTopSort;
    }

    public String getSkinName() {
        return skinName;
    }

    public void setSkinName(String skinName) {
        this.skinName = skinName;
    }
}
